﻿* Encoding: UTF-8.
************************************************************
*****Read data. Insert your data path before backslash between the quotation marks of /FILE="\Exp2_Rawdat_included.dat".

GET DATA  /TYPE=TXT
  /FILE=
    "\Exp2_Rawdat_included.dat"
  /ENCODING='Locale'
  /DELCASE=LINE
  /DELIMITERS="\t"
  /ARRANGEMENT=DELIMITED
  /FIRSTCASE=2
  /IMPORTCASE=ALL
  /VARIABLES=
  Subject F1.0
  Group F1.0
  Block F1.0
  Trial F3.0
  BlockTrial F3.0
  RT F4.0
  RTn1 F4.0
  MT F4.0
  MTn1 F4.0
  Typ F1.0
  Typn1 F1.0
  IT F8.0
  intention F1.0
  Code F2.0
  MAD F7.0
  AUC F8.0
  Curv F6.0
  TTP F2.0
  FDT F6.0
  Angle F6.0
  Side_lr F2.0
  Trialfilter F1.0
  x0 F3.0
  x1 F7.0
  x2 F7.0
  x3 F7.0
  x4 F7.0
  x5 F7.0
  x6 F8.0
  x7 F7.0
  x8 F7.0
  x9 F6.0
  x10 F3.0
  y0 F2.0
  y1 F6.0
  y2 F6.0
  y3 F6.0
  y4 F6.0
  y5 F6.0
  y6 F6.0
  y7 F6.0
  y8 F6.0
  y9 F6.0
  y10 F3.0.
EXECUTE.
DATASET NAME Rawdat WINDOW=FRONT.
DATASET ACTIVATE Rawdat.

SORT CASES BY Subject Trial.
EXECUTE.


************************************************************
*****Variables
    
    *Group: no groups, always 1
    *RT: time that passed from touching the starting area until leaving it (IT in manuscript)
    *RTn1: RT from the preceding trial
    *MT: time that passed from leaving the starting area until the finger stopped touching the iPad was the movement time (MT in manuscript)
    *MTn1: MT from the preceding trial

    *Typ: 

        *1 = routine questions, cue indicates honest response, correct response delivered > corresponding routine response
        *2 = routine questions, cue indicates honest response, erreneous response delivered 
        *3 = mission question, cue indicates honest response (false alibi indicates dishonest response), erreneous response delivered 
        *4 = mission question, cue indicates honest response (false alibi indicates dishonest response), correct response delivered  > non-corresponding mission response
        *5 = spatial omission (participant stopped touching the screen outside of target areas)
        *6 = routine questions, cue indicates opposite response, erreneous response delivered
        *7 = routine questions, cue indicates opposite response, correct response delivered > non-corresponding routine response
        *8 = mission questions, cue indicates opposite response (false alibi indicates honest response), correct response delivered > corresponding mission response
        *9 = mission questions, cue indicates opposite response (false alibi indicates honest response), erreneous response delivered
        *10 = temporal omission (RD, here IT, > 1500 ms; IT, here RT, > 500 ms)
    
    *IT: time that passed between question onset and touching the starting area (RD in manuscript)
    *intention: 0 = cue color indicates opposite responding; 1 = cue color indicates honest responding

    *code: questions 
        
        *practice questions = 81-86
        
        *routine questions
        Hast du eine Straße überquert? = 1
        Hast du mit jemandem gesprochen? = 2
        Hast du eine Tür durchquert? = 3
        Hast du ein Dokument unterzeichnet? = 4
        Hast du dir Schuhe angezogen? = 5
        Hast du ein Kamel gestreichelt? = 6
        Hast du im Lottospiel gewonnen? = 7
        Hast du ein Fenster zerstört? = 8
        Hast du die Polizei angerufen? = 9
        Hast du einen Pilz gesammelt? = 10
        
        *mission questions
        Hast du ein Dreieck gezeichnet? = 11
        Hast du ein Blatt zerrissen? = 12
        Hast du eine Box geöffnet? = 13
        Hast du ein Papierstück versteckt? = 14
        Hast du einen Kreis gezeichnet? = 15
        Hast du eine Email verfasst? = 16
        Hast du eine Datei gesendet? = 17
        Hast du eine Tabelle geöffnet? = 18
        Hast du den USB-Stick benutzt? = 19
        Hast du den PC eingeschaltet? = 20

*MAD (Maximum absolute distance): maximum absolute euclidean distance of the actual trajectory between a virtual perfect line from the point where the finger left the start area to the end point of the movement and the the actual trajectory  
*AUC (area under the curve): area between the actual trajectory and the virtual perfect line mentioned above
*AUC (area under the curve): area between the actual trajectory and the virtual perfect line mentioned above
*Curv (Curvature): Ratio of the length of the actual trajectory and the length of the virtual perfect line
*TTP (Time to peak velocity): Point in time (in % movement) with the highest movement velocity
*FDT (final distance to target): euclidian distance between endpoint of the actual trajectory and center of the target area
*Angle (starting angle): staring angle of the finger movement when leaving the starting area, relative to a vertical midline
*Side_lr (response side): -1 = movement to the left target area; 1 = movement to the right; 0 = no analysis due to error (see trialfilter)
*trialfilter: 0 = trial excluded in trajectory aggregation because of an error (Typ = 2/3/5/6/9), and first trial of each block
*x and y: time-normalized coordinates.
*code_n1 (computed in the script): question code of trial n-1 
*code_seq (computed in the script): 0 = different questions in trial n-1 and trial n; 1 = same questions in trial n-1 und trial n (also considers repetitions from the last trial of a block to the first trial of the next block) 
*qtype (computed in the script): 0 = mission question; 1 = routine question
*correspondence (computed in script): 0 = non-corresponding activity and response; 1 = corresponding activity and response
*acc (computed in the script): 0 = error; 1 = correct


*********************************
*******compute variables.

IF  (IT > 1500 | RT > 500) Typ=10.
EXECUTE.

COMPUTE code_n1=LAG(Code).
VARIABLE LEVEL  code_n1(NOMINAL).
FORMATS  code_n1(F6.0).
EXECUTE.

IF  (Code = code_n1) code_seq=1.
IF  (Code ~= code_n1) code_seq=0.
FORMATS  code_seq(F6.0).
EXECUTE.

RECODE code_seq (SYSMIS=0).
EXECUTE.

IF (Code < 11) qtype=1.
IF (Code > 10 & Code < 21) qtype=0.
VARIABLE LEVEL  qtype(NOMINAL).
FORMATS  qtype(F6.0).
EXECUTE.

IF  (qtype = 0 & intention = 0) correspondence=1.
IF  (qtype = 0 & intention = 1) correspondence=0.
IF  (qtype = 1 & intention = 0) correspondence=0.
IF  (qtype = 1 & intention = 1) correspondence=1.
FORMATS correspondence (F6.0).
EXECUTE.

COMPUTE acc = 0.
IF  (Typ = 1 | Typ = 4 | Typ = 7 |Typ = 8) acc=1.
FORMATS  acc(F6.0).
EXECUTE.

*********************************
*******Selecting trials.

*eliminate practice questions and blocks and first trial of each block.
FILTER OFF.
USE ALL.
SELECT IF (Code < 80 & Block > 1 & BlockTrial > 1).
EXECUTE.

*select trials where question in trial n is different from question in trial n-1.
USE ALL.
COMPUTE question_filter=(code_seq = 0).
FORMATS question_filter (f1.0).
FILTER BY question_filter.
EXECUTE.


*********************************
********PE analyses: question type x correspondence.

DATASET ACTIVATE Rawdat.

*select correct and commission error trials.
USE ALL.
COMPUTE comfilter=(Typ ~= 5 & Typ ~= 10).
FORMATS comfilter (f1.0).
FILTER BY comfilter.
EXECUTE.

*use comfilter and question_filter.
USE ALL.
COMPUTE globalcomfilter=(question_filter= 1 & comfilter = 1).
FORMATS globalcomfilter (f1.0).
FILTER BY globalcomfilter.
EXECUTE.

*aggregate data in a new data sheet.
DATASET DECLARE Errdat.
AGGREGATE
  /OUTFILE='Errdat'
  /BREAK=Subject qtype correspondence acc
  /N_BREAK=N.
DATASET ACTIVATE Errdat.

*sort data for ANOVA.
SORT CASES BY subject qtype correspondence acc.
CASESTOVARS
  /ID=subject
  /INDEX= qtype correspondence acc
  /GROUPBY=VARIABLE.

*missing values (no error committed) > 0.
RECODE N_BREAK.0.0.0 N_BREAK.0.0.1 N_BREAK.0.1.0 N_BREAK.0.1.1 N_BREAK.1.0.0 N_BREAK.1.0.1 
    N_BREAK.1.1.0 N_BREAK.1.1.1 (SYSMIS=0).
EXECUTE.

*compute PE.
COMPUTE PE.0.0 = (N_BREAK.0.0.0 / (N_BREAK.0.0.0 + N_BREAK.0.0.1))*100.
COMPUTE PE.0.1 = (N_BREAK.0.1.0 / (N_BREAK.0.1.0 + N_BREAK.0.1.1))*100.
COMPUTE PE.1.0 = (N_BREAK.1.0.0 / (N_BREAK.1.0.0 + N_BREAK.1.0.1))*100.
COMPUTE PE.1.1 = (N_BREAK.1.1.0 / (N_BREAK.1.1.0 + N_BREAK.1.1.1))*100.
EXECUTE.

*check for PEs >= 50 in any cell.
USE ALL.
COMPUTE sbjct_filter=(PE.0.0 < 50 & PE.0.1 < 50 & PE.1.0 < 50 & PE.1.1 < 50).
FORMATS sbjct_filter (f1.0).
Filter BY sbjct_filter.
EXECUTE. 

*ANOVA and t-test.
GLM PE.0.0 PE.0.1 PE.1.0 PE.1.1
  /WSFACTOR=qtype 2 Polynomial correspondence 2 Polynomial 
  /METHOD=SSTYPE(3)
  /PLOT=PROFILE(qtype*correspondence)
  /PRINT=DESCRIPTIVE ETASQ 
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=qtype correspondence qtype*correspondence.

T-TEST PAIRS=PE.1.0 PE.0.0 WITH PE.1.1 PE.0.1 (PAIRED)
  /CRITERIA=CI(.9500)
  /MISSING=ANALYSIS.


************************************************************
*RT analyses: qtype x correspondence .

DATASET ACTIVATE Rawdat.

*select accurate trials.
USE ALL.
COMPUTE acc_filter=(acc = 1).
FORMATS acc_filter (f1.0).
FILTER BY acc_filter.
EXECUTE.

*select question switches and accurate trials.
USE ALL.
COMPUTE RT_filter = (question_filter = 1 & acc_filter = 1).
FORMATS RT_filter (f1.0).
Filter BY RT_filter.
EXECUTE.

*standardise RTs separately for each cell and eliminate outliers. 
SORT CASES  BY Subject qtype correspondence.
SPLIT FILE SEPARATE BY Subject qtype correspondence.

DELETE VARIABLES ZRT ZMT ZIT ZAUC.
EXECUTE.

DESCRIPTIVES VARIABLES=RT MT IT AUC
  /SAVE
  /STATISTICS=MEAN STDDEV SEMEAN.

COMPUTE z_filter=((ABS(ZRT) <= 2.5) & ABS(ZMT) <= 2.5 & ABS(ZIT) <= 2.5 & ABS(ZAUC) <= 2.5).
FORMATS z_filter (f1.0).
EXECUTE.

SPLIT FILE OFF.
SORT CASES BY Subject Trial.
FILTER OFF.

*use all filters (question, accuracy and outliers).
USE ALL.
COMPUTE globalRT_filter = (RT_filter = 1 & z_filter = 1).
FORMATS globalRT_filter (f1.0).
Filter BY globalRT_filter.
EXECUTE.

*aggregate data in a new data sheet: RD, IT, MT and AUC.
DATASET DECLARE RTdat.
AGGREGATE
  /OUTFILE='RTdat'
  /BREAK=subject qtype correspondence
  /RD=MEAN(IT)
  /IT=MEAN(RT)
  /MT=MEAN(MT)
  /AUC=MEAN(AUC)
  /NRTs=N.

DATASET ACTIVATE RTdat.

*sort data for ANOVA.
SORT CASES BY subject qtype correspondence.
CASESTOVARS
  /ID=subject
  /INDEX= qtype correspondence
  /GROUPBY=VARIABLE.

*ANOVAs and t-tests.
GLM RD.0.0 RD.0.1 RD.1.0 RD.1.1
  /WSFACTOR=qtype 2 Polynomial correspondence 2 Polynomial 
  /METHOD=SSTYPE(3)
  /PLOT=PROFILE(qtype*correspondence)
  /PRINT=DESCRIPTIVE ETASQ 
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=qtype correspondence qtype*correspondence.

T-TEST PAIRS=RD.1.0 RD.0.0 WITH RD.1.1 RD.0.1 (PAIRED)
  /CRITERIA=CI(.9500)
  /MISSING=ANALYSIS.

GLM IT.0.0 IT.0.1 IT.1.0 IT.1.1
 /WSFACTOR=qtype 2 Polynomial correspondence 2 Polynomial 
  /METHOD=SSTYPE(3)
  /PLOT=PROFILE(qtype*correspondence)
  /PRINT=DESCRIPTIVE ETASQ 
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=qtype correspondence qtype*correspondence.

T-TEST PAIRS=IT.1.0 IT.0.0 WITH IT.1.1 IT.0.1 (PAIRED)
  /CRITERIA=CI(.9500)
  /MISSING=ANALYSIS.

GLM MT.0.0 MT.0.1 MT.1.0 MT.1.1
  /WSFACTOR=qtype 2 Polynomial correspondence 2 Polynomial 
  /METHOD=SSTYPE(3)
  /PLOT=PROFILE(qtype*correspondence)
  /PRINT=DESCRIPTIVE ETASQ 
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=qtype correspondence qtype*correspondence.

T-TEST PAIRS=MT.1.0 MT.0.0 WITH MT.1.1 MT.0.1 (PAIRED)
  /CRITERIA=CI(.9500)
  /MISSING=ANALYSIS.

GLM AUC.0.0 AUC.0.1 AUC.1.0 AUC.1.1
  /WSFACTOR=qtype 2 Polynomial correspondence 2 Polynomial 
  /METHOD=SSTYPE(3)
  /PLOT=PROFILE(qtype*correspondence)
  /PRINT=DESCRIPTIVE ETASQ 
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=qtype correspondence qtype*correspondence.

T-TEST PAIRS=AUC.1.0 AUC.0.0 WITH AUC.1.1 AUC.0.1 (PAIRED)
  /CRITERIA=CI(.9500)
  /MISSING=ANALYSIS.


************************************************************
*Filter descriptives.

DATASET ACTIVATE Rawdat.
USE ALL.

FREQUENCIES VARIABLES= question_filter
  /STATISTICS=SUM
  /ORDER=ANALYSIS.

FILTER BY question_filter.

FREQUENCIES VARIABLES= comfilter z_filter
  /STATISTICS=SUM
  /ORDER=ANALYSIS.


************************************************************
*aggregate data for trajectory figures.

DATASET ACTIVATE Rawdat.

Filter BY globalRT_filter.
EXECUTE.

DATASET DECLARE Plotdat.
AGGREGATE
  /OUTFILE='Plotdat'
  /BREAK=qtype correspondence
  /x0_mean=MEAN(x0) 
  /x1_mean=MEAN(x1) 
  /x2_mean=MEAN(x2) 
  /x3_mean=MEAN(x3) 
  /x4_mean=MEAN(x4) 
  /x5_mean=MEAN(x5) 
  /x6_mean=MEAN(x6) 
  /x7_mean=MEAN(x7) 
  /x8_mean=MEAN(x8) 
  /x9_mean=MEAN(x9) 
  /x10_mean=MEAN(x10) 
  /y0_mean=MEAN(y0) 
  /y1_mean=MEAN(y1) 
  /y2_mean=MEAN(y2) 
  /y3_mean=MEAN(y3) 
  /y4_mean=MEAN(y4) 
  /y5_mean=MEAN(y5) 
  /y6_mean=MEAN(y6) 
  /y7_mean=MEAN(y7) 
  /y8_mean=MEAN(y8) 
  /y9_mean=MEAN(y9) 
  /y10_mean=MEAN(y10).
DATASET ACTIVATE Plotdat.

*Daten sortieren.
SORT CASES BY qtype correspondence.

